<?php

/**
 * The metabox-specific functionality of the plugin.
 *
 * @since      	1.0
 * @package 	Leadferno
 * @subpackage 	Leadferno/admin
 */

class Leadferno_Admin_Metaboxes
{
	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0
	 * @param 		string 			$plugin_name 		The name of this plugin.
	 * @param 		string 			$version 			The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Meta box setup function for leadbox.
	 *
	 * @since 		1.0
	 */
	public function leadbox_meta_boxes_setup()
	{
		/* Add meta boxes on the 'add_meta_boxes' hook. */
		add_action('add_meta_boxes', array($this, 'leadbox_add_meta'));

		/* Save post meta on the 'save_post' hook. */
		add_action('save_post', array($this, 'leadbox_save_meta'));
	}

	/**
	 * Create one or more meta boxes to be displayed on the post editor screen - leadbox
	 *
	 * @since 		1.0
	 */
	public function leadbox_add_meta()
	{
		add_meta_box(
			'leadbox_options',
			apply_filters($this->plugin_name . '-metabox-title-leadbox-options', esc_html__('Options', 'leadferno')),
			array($this, 'leadbox_metabox'),
			'leadbox', // post type
			'normal',
			'default',
			array(
				'file' => 'leadbox-options'
			)
		);
	}

	/**
	 * Calls a metabox file specified in the add_meta_box args - leadbox
	 *
	 * @since 		1.0
	 * @return 		void
	 */
	public function leadbox_metabox($post, $params)
	{
		if (!is_admin())
			return;

		if ('leadbox' !== $post->post_type)
			return;

		if (!empty($params['args']['classes']))
			$classes = 'repeater ' . $params['args']['classes'];

		include(plugin_dir_path(__FILE__) . 'partials/leadferno-admin-metabox-' . $params['args']['file'] . '.php');
	}

	/**
	 * Returns an array of the all the metabox fields and their respective types - leadbox
	 *
	 * @since 		1.0
	 * @access 		public
	 * @return 		array 		Metabox fields and types
	 */
	private function leadbox_get_metabox_fields()
	{
		$fields = array();
		$fields[] = array('leadbox-enable', 'radio');
		$fields[] = array('leadbox-bid', 'text');
		$fields[] = array('leadbox-type', 'radio');
		$fields[] = array('leadbox-display', 'select');
		$fields[] = array('leadbox-pages', 'checkbox');
		$fields[] = array('leadbox-posts', 'checkbox');
		$fields[] = array('leadbox-urls', 'text');

		return $fields;
	}

	/**
	 * Saves metabox data - leadbox
	 *
	 * @since 		1.0
	 * @access 		public
	 * @param 		int 		$post_id 		The post ID
	 * @param 		object 		$object 		The post object
	 * @return 		void
	 */
	public function leadbox_save_meta($post_id, $object = null)
	{
		//wp_die( '<pre>' . print_r( $_POST ) . '</pre>' );

		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
			return $post_id;

		if (!current_user_can('edit_post', $post_id))
			return $post_id;

		if (!isset($_POST['post_type']))
			return;

		$safe_post_type = $this->sanitizer('text', $_POST['post_type']);

		if ($safe_post_type !== 'leadbox')
			return $post_id;

		$nonce_check = $this->check_nonces($_POST, $type = 'leadbox');

		if (0 < $nonce_check)
			return $post_id;

		$metas = $this->leadbox_get_metabox_fields();

		foreach ($metas as $meta)
		{
			$name = $this->sanitizer('text', $meta[0]);
			$type = $meta[1];

			if (is_array($_POST[$name]))
				$new_value = $this->sanitizer('array', $_POST[$name]);
			else
				$new_value = $this->sanitizer($type, $_POST[$name]);

			update_post_meta($post_id, $name, $new_value);
		} // foreach
	}

	/**
	 * Check each nonce. If any don't verify, $nonce_check is increased.
	 * If all nonces verify, returns 0.
	 *
	 * @since 		1.0
	 * @access 		public
	 * @return 		int 		The value of $nonce_check
	 */
	private function check_nonces($posted, $type)
	{
		$nonces = array();
		$nonce_check = 0;

		$nonces[] = $type . '_options';

		foreach ($nonces as $nonce)
		{
			if (!isset($posted[$nonce]))
				$nonce_check++;

			if (isset($posted[$nonce]) && !wp_verify_nonce($posted[$nonce], $this->plugin_name))
				$nonce_check++;
		}

		return $nonce_check;
	}

	/**
	 * Sanitizes input.
	 *
	 * @since 		1.0
	 * @access 		public
	 * @return 		array 		Metabox fields and types
	 */
	private function sanitizer($type, $data)
	{
		if (empty($type))
			return;

		if (empty($data))
			return;

		$return = '';
		$sanitizer = new Leadferno_Sanitize();

		$sanitizer->set_data($data);
		$sanitizer->set_type($type);

		$return = $sanitizer->clean();

		unset($sanitizer);

		return $return;
	}
}
