<?php

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0
 * @package    Leadferno
 * @subpackage Leadferno/includes
 */

class Leadferno
{
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0
	 * @access   protected
	 * @var      Leadferno_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0
	 */
	public function __construct()
	{
		$this->plugin_name = 'leadferno';
		$this->version = '1.1';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		$this->define_metabox_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Leadferno_Loader. Orchestrates the hooks of the plugin.
	 * - Leadferno_i18n. Defines internationalization functionality.
	 * - Leadferno_Admin. Defines all hooks for the admin area.
	 * - Leadferno_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0
	 * @access   private
	 */
	private function load_dependencies()
	{
		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-leadferno-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-leadferno-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-leadferno-admin.php';

		/**
		 * The class responsible for defining all actions relating to metaboxes.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-leadferno-admin-metaboxes.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-leadferno-public.php';

		/**
		 * The class responsible for sanitizing user input
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-leadferno-sanitize.php';

		$this->loader = new Leadferno_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Leadferno_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0
	 * @access   private
	 */
	private function set_locale()
	{
		$plugin_i18n = new Leadferno_i18n();

		$this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0
	 * @access   private
	 */
	private function define_admin_hooks()
	{
		$plugin_admin = new Leadferno_Admin($this->get_plugin_name(), $this->get_version());

		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');

		// leadbox post type
		$this->loader->add_action('init', $plugin_admin, 'leadbox_register_post_type');

		// Add columns to leadbox
		$this->loader->add_filter( 'manage_leadbox_posts_columns' , $plugin_admin, 'leadbox_add_column_status' );
		$this->loader->add_action( 'manage_leadbox_posts_custom_column' , $plugin_admin, 'leadbox_display_column_status', 10, 2 );
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0
	 * @access   private
	 */
	private function define_public_hooks()
	{
		$plugin_public = new Leadferno_Public($this->get_plugin_name(), $this->get_version());

		// Add leadferno script to wp_footer hook
		$this->loader->add_action('wp_footer', $plugin_public, 'leadferno_add_script');
	}

	/**
	 * Register all of the hooks related to metaboxes.
	 *
	 * @since 	 1.0
	 * @access 	 private
	 */
	private function define_metabox_hooks()
	{
		$plugin_metaboxes = new Leadferno_Admin_Metaboxes($this->get_plugin_name(), $this->get_version());

		/* Fire our meta box setup function on the post editor screen. */
		// leadbox
		$this->loader->add_action('load-post.php', $plugin_metaboxes, 'leadbox_meta_boxes_setup');
		$this->loader->add_action('load-post-new.php', $plugin_metaboxes, 'leadbox_meta_boxes_setup');
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0
	 */
	public function run()
	{
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since    1.0
	 * @return   string    The name of the plugin.
	 */
	public function get_plugin_name()
	{
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since    1.0
	 * @return   Leadferno_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader()
	{
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since    1.0
	 * @return   string    The version number of the plugin.
	 */
	public function get_version()
	{
		return $this->version;
	}
}
